import boto3

acm = boto3.client("acm")

""":type : pyboto3.acm"""

apigateway = boto3.client("apigateway")

""":type : pyboto3.apigateway"""

application_autoscaling = boto3.client("application-autoscaling")

""":type : pyboto3.application_autoscaling"""

appstream = boto3.client("appstream")

""":type : pyboto3.appstream"""

athena = boto3.client("athena")

""":type : pyboto3.athena"""

autoscaling = boto3.client("autoscaling")

""":type : pyboto3.autoscaling"""

batch = boto3.client("batch")

""":type : pyboto3.batch"""

budgets = boto3.client("budgets")

""":type : pyboto3.budgets"""

clouddirectory = boto3.client("clouddirectory")

""":type : pyboto3.clouddirectory"""

cloudformation = boto3.client("cloudformation")

""":type : pyboto3.cloudformation"""

cloudfront = boto3.client("cloudfront")

""":type : pyboto3.cloudfront"""

cloudhsm = boto3.client("cloudhsm")

""":type : pyboto3.cloudhsm"""

cloudsearch = boto3.client("cloudsearch")

""":type : pyboto3.cloudsearch"""

cloudsearchdomain = boto3.client("cloudsearchdomain")

""":type : pyboto3.cloudsearchdomain"""

cloudtrail = boto3.client("cloudtrail")

""":type : pyboto3.cloudtrail"""

cloudwatch = boto3.client("cloudwatch")

""":type : pyboto3.cloudwatch"""

codebuild = boto3.client("codebuild")

""":type : pyboto3.codebuild"""

codecommit = boto3.client("codecommit")

""":type : pyboto3.codecommit"""

codedeploy = boto3.client("codedeploy")

""":type : pyboto3.codedeploy"""

codepipeline = boto3.client("codepipeline")

""":type : pyboto3.codepipeline"""

codestar = boto3.client("codestar")

""":type : pyboto3.codestar"""

cognito_identity = boto3.client("cognito-identity")

""":type : pyboto3.cognito_identity"""

cognito_idp = boto3.client("cognito-idp")

""":type : pyboto3.cognito_idp"""

cognito_sync = boto3.client("cognito-sync")

""":type : pyboto3.cognito_sync"""

config = boto3.client("config")

""":type : pyboto3.config"""

cur = boto3.client("cur")

""":type : pyboto3.cur"""

datapipeline = boto3.client("datapipeline")

""":type : pyboto3.datapipeline"""

devicefarm = boto3.client("devicefarm")

""":type : pyboto3.devicefarm"""

directconnect = boto3.client("directconnect")

""":type : pyboto3.directconnect"""

discovery = boto3.client("discovery")

""":type : pyboto3.discovery"""

dms = boto3.client("dms")

""":type : pyboto3.dms"""

ds = boto3.client("ds")

""":type : pyboto3.ds"""

dynamodb = boto3.client("dynamodb")

""":type : pyboto3.dynamodb"""

dynamodbstreams = boto3.client("dynamodbstreams")

""":type : pyboto3.dynamodbstreams"""

ec2 = boto3.client("ec2")

""":type : pyboto3.ec2"""

ecr = boto3.client("ecr")

""":type : pyboto3.ecr"""

ecs = boto3.client("ecs")

""":type : pyboto3.ecs"""

efs = boto3.client("efs")

""":type : pyboto3.efs"""

elasticache = boto3.client("elasticache")

""":type : pyboto3.elasticache"""

elasticbeanstalk = boto3.client("elasticbeanstalk")

""":type : pyboto3.elasticbeanstalk"""

elastictranscoder = boto3.client("elastictranscoder")

""":type : pyboto3.elastictranscoder"""

elb = boto3.client("elb")

""":type : pyboto3.elb"""

elbv2 = boto3.client("elbv2")

""":type : pyboto3.elbv2"""

emr = boto3.client("emr")

""":type : pyboto3.emr"""

es = boto3.client("es")

""":type : pyboto3.es"""

events = boto3.client("events")

""":type : pyboto3.events"""

firehose = boto3.client("firehose")

""":type : pyboto3.firehose"""

gamelift = boto3.client("gamelift")

""":type : pyboto3.gamelift"""

glacier = boto3.client("glacier")

""":type : pyboto3.glacier"""

health = boto3.client("health")

""":type : pyboto3.health"""

iam = boto3.client("iam")

""":type : pyboto3.iam"""

importexport = boto3.client("importexport")

""":type : pyboto3.importexport"""

inspector = boto3.client("inspector")

""":type : pyboto3.inspector"""

iot = boto3.client("iot")

""":type : pyboto3.iot"""

iot_data = boto3.client("iot-data")

""":type : pyboto3.iot_data"""

kinesis = boto3.client("kinesis")

""":type : pyboto3.kinesis"""

kinesisanalytics = boto3.client("kinesisanalytics")

""":type : pyboto3.kinesisanalytics"""

kms = boto3.client("kms")

""":type : pyboto3.kms"""

lambda_ = boto3.client("lambda")

""":type : pyboto3.lambda_"""

lex_models = boto3.client("lex-models")

""":type : pyboto3.lex_models"""

lex_runtime = boto3.client("lex-runtime")

""":type : pyboto3.lex_runtime"""

lightsail = boto3.client("lightsail")

""":type : pyboto3.lightsail"""

logs = boto3.client("logs")

""":type : pyboto3.logs"""

machinelearning = boto3.client("machinelearning")

""":type : pyboto3.machinelearning"""

marketplace_entitlement = boto3.client("marketplace-entitlement")

""":type : pyboto3.marketplace_entitlement"""

marketplacecommerceanalytics = boto3.client("marketplacecommerceanalytics")

""":type : pyboto3.marketplacecommerceanalytics"""

meteringmarketplace = boto3.client("meteringmarketplace")

""":type : pyboto3.meteringmarketplace"""

mturk = boto3.client("mturk")

""":type : pyboto3.mturk"""

opsworks = boto3.client("opsworks")

""":type : pyboto3.opsworks"""

opsworkscm = boto3.client("opsworkscm")

""":type : pyboto3.opsworkscm"""

organizations = boto3.client("organizations")

""":type : pyboto3.organizations"""

pinpoint = boto3.client("pinpoint")

""":type : pyboto3.pinpoint"""

polly = boto3.client("polly")

""":type : pyboto3.polly"""

rds = boto3.client("rds")

""":type : pyboto3.rds"""

redshift = boto3.client("redshift")

""":type : pyboto3.redshift"""

rekognition = boto3.client("rekognition")

""":type : pyboto3.rekognition"""

resourcegroupstaggingapi = boto3.client("resourcegroupstaggingapi")

""":type : pyboto3.resourcegroupstaggingapi"""

route53 = boto3.client("route53")

""":type : pyboto3.route53"""

route53domains = boto3.client("route53domains")

""":type : pyboto3.route53domains"""

s3 = boto3.client("s3")

""":type : pyboto3.s3"""

sdb = boto3.client("sdb")

""":type : pyboto3.sdb"""

servicecatalog = boto3.client("servicecatalog")

""":type : pyboto3.servicecatalog"""

ses = boto3.client("ses")

""":type : pyboto3.ses"""

shield = boto3.client("shield")

""":type : pyboto3.shield"""

sms = boto3.client("sms")

""":type : pyboto3.sms"""

snowball = boto3.client("snowball")

""":type : pyboto3.snowball"""

sns = boto3.client("sns")

""":type : pyboto3.sns"""

sqs = boto3.client("sqs")

""":type : pyboto3.sqs"""

ssm = boto3.client("ssm")

""":type : pyboto3.ssm"""

stepfunctions = boto3.client("stepfunctions")

""":type : pyboto3.stepfunctions"""

storagegateway = boto3.client("storagegateway")

""":type : pyboto3.storagegateway"""

sts = boto3.client("sts")

""":type : pyboto3.sts"""

support = boto3.client("support")

""":type : pyboto3.support"""

swf = boto3.client("swf")

""":type : pyboto3.swf"""

waf = boto3.client("waf")

""":type : pyboto3.waf"""

waf_regional = boto3.client("waf-regional")

""":type : pyboto3.waf_regional"""

workdocs = boto3.client("workdocs")

""":type : pyboto3.workdocs"""

workspaces = boto3.client("workspaces")

""":type : pyboto3.workspaces"""

xray = boto3.client("xray")

""":type : pyboto3.xray"""

