'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def batch_meter_usage(UsageRecords=None, ProductCode=None):
    """
    BatchMeter is called from a SaaS application listed on the AWS Marketplace to post metering records for a set of customers.
    For identical requests, the API is idempotent; requests can be retried with the same records or a subset of the input records.
    Every request to BatchMeter is for one product. If you need to meter usage for multiple products, you must make multiple calls to BatchMeterUsage.
    BatchMeterUsage can process up to 25 UsageRecords at a time.
    See also: AWS API Documentation
    
    
    :example: response = client.batch_meter_usage(
        UsageRecords=[
            {
                'Timestamp': datetime(2015, 1, 1),
                'CustomerIdentifier': 'string',
                'Dimension': 'string',
                'Quantity': 123
            },
        ],
        ProductCode='string'
    )
    
    
    :type UsageRecords: list
    :param UsageRecords: [REQUIRED]
            The set of UsageRecords to submit. BatchMeterUsage accepts up to 25 UsageRecords at a time.
            (dict) --A UsageRecord indicates a quantity of usage for a given product, customer, dimension and time.
            Multiple requests with the same UsageRecords as input will be deduplicated to prevent double charges.
            Timestamp (datetime) -- [REQUIRED]Timestamp of the hour, recorded in UTC. The seconds and milliseconds portions of the timestamp will be ignored.
            Your application can meter usage for up to one hour in the past.
            CustomerIdentifier (string) -- [REQUIRED]The CustomerIdentifier is obtained through the ResolveCustomer operation and represents an individual buyer in your application.
            Dimension (string) -- [REQUIRED]During the process of registering a product on AWS Marketplace, up to eight dimensions are specified. These represent different units of value in your application.
            Quantity (integer) -- [REQUIRED]The quantity of usage consumed by the customer for the given dimension and time.
            
            

    :type ProductCode: string
    :param ProductCode: [REQUIRED]
            Product code is used to uniquely identify a product in AWS Marketplace. The product code should be the same as the one used during the publishing of a new product.
            

    :rtype: dict
    :return: {
        'Results': [
            {
                'UsageRecord': {
                    'Timestamp': datetime(2015, 1, 1),
                    'CustomerIdentifier': 'string',
                    'Dimension': 'string',
                    'Quantity': 123
                },
                'MeteringRecordId': 'string',
                'Status': 'Success'|'CustomerNotSubscribed'|'DuplicateRecord'
            },
        ],
        'UnprocessedRecords': [
            {
                'Timestamp': datetime(2015, 1, 1),
                'CustomerIdentifier': 'string',
                'Dimension': 'string',
                'Quantity': 123
            },
        ]
    }
    
    
    :returns: 
    Success - The UsageRecord was accepted and honored by BatchMeterUsage.
    CustomerNotSubscribed - The CustomerIdentifier specified is not subscribed to your product. The UsageRecord was not honored. Future UsageRecords for this customer will fail until the customer subscribes to your product.
    DuplicateRecord - Indicates that the UsageRecord was invalid and not honored. A previously metered UsageRecord had the same customer, dimension, and time, but a different quantity.
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass

def meter_usage(ProductCode=None, Timestamp=None, UsageDimension=None, UsageQuantity=None, DryRun=None):
    """
    API to emit metering records. For identical requests, the API is idempotent. It simply returns the metering record ID.
    Meter is authenticated on the buyer's AWS account, generally when running from an EC2 instance on the AWS Marketplace.
    See also: AWS API Documentation
    
    
    :example: response = client.meter_usage(
        ProductCode='string',
        Timestamp=datetime(2015, 1, 1),
        UsageDimension='string',
        UsageQuantity=123,
        DryRun=True|False
    )
    
    
    :type ProductCode: string
    :param ProductCode: [REQUIRED]
            Product code is used to uniquely identify a product in AWS Marketplace. The product code should be the same as the one used during the publishing of a new product.
            

    :type Timestamp: datetime
    :param Timestamp: [REQUIRED]
            Timestamp of the hour, recorded in UTC. The seconds and milliseconds portions of the timestamp will be ignored.
            

    :type UsageDimension: string
    :param UsageDimension: [REQUIRED]
            It will be one of the fcp dimension name provided during the publishing of the product.
            

    :type UsageQuantity: integer
    :param UsageQuantity: [REQUIRED]
            Consumption value for the hour.
            

    :type DryRun: boolean
    :param DryRun: [REQUIRED]
            Checks whether you have the permissions required for the action, but does not make the request. If you have the permissions, the request returns DryRunOperation; otherwise, it returns UnauthorizedException.
            

    :rtype: dict
    :return: {
        'MeteringRecordId': 'string'
    }
    
    
    :returns: 
    (dict) --
    MeteringRecordId (string) --
    
    
    
    """
    pass

def resolve_customer(RegistrationToken=None):
    """
    ResolveCustomer is called by a SaaS application during the registration process. When a buyer visits your website during the registration process, the buyer submits a registration token through their browser. The registration token is resolved through this API to obtain a CustomerIdentifier and product code.
    See also: AWS API Documentation
    
    
    :example: response = client.resolve_customer(
        RegistrationToken='string'
    )
    
    
    :type RegistrationToken: string
    :param RegistrationToken: [REQUIRED]
            When a buyer visits your website during the registration process, the buyer submits a registration token through the browser. The registration token is resolved to obtain a CustomerIdentifier and product code.
            

    :rtype: dict
    :return: {
        'CustomerIdentifier': 'string',
        'ProductCode': 'string'
    }
    
    
    """
    pass

